@@ -8,10 +8,10 @@ pyside_library_soversion = "6.10"
 version = "6.10.0"
 version_info = (6, 10, 0, "", "")
 
-__build_date__ = '2025-10-17T16:59:04+00:00'
-
-
-
+__build_date__ = '2025-10-21T12:20:44+00:00'
+__build_commit_date__ = '2025-10-17T17:03:56+00:00'
+__build_commit_hash__ = '483a9407db5e85f222180cab25b9a018c4513a4c'
+__build_commit_hash_described__ = '6.10.0-3'
 
 
 
